/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package nl.cloudfarming.client.sensor.area;

import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.MultiPolygon;
import com.vividsolutions.jts.io.ParseException;
import com.vividsolutions.jts.io.WKTReader;
import java.util.List;
import nl.cloudfarming.client.geoviewer.LayerObject;
import nl.cloudfarming.client.geoviewer.Rastered;
import nl.cloudfarming.client.model.Plot;
import nl.cloudfarming.client.model.SensorData;
import org.geotools.coverage.grid.GridCoverage2D;
import org.geotools.geometry.jts.JTSFactoryFinder;
import org.openide.nodes.Sheet;
import org.openide.util.Exceptions;

/**
 *
 * @author monezz
 */
public class AreaSensorDataLayerObject implements LayerObject<MultiPolygon,Plot>, Rastered {

    private final MultiPolygon geometry;
    private final Plot plot;
    private final GridCoverage2D raster;
    

    public AreaSensorDataLayerObject(Plot plot, List<SensorData> SensorData) {

        try {
            GeometryFactory geometryFactory = JTSFactoryFinder.getGeometryFactory(null);
            WKTReader reader = new WKTReader(geometryFactory);
            geometry = (MultiPolygon) reader.read(plot.getWKT());
            this.plot = plot;
            this.raster = RasterFactory.createRaster(SensorData);
        } catch (ParseException ex) {
            Exceptions.printStackTrace(ex);
            throw new RuntimeException(ex);
        }
    }

    @Override
    public MultiPolygon getGeometry() {
        return this.geometry;
    }

     @Override
    public String getKey() {
        return Long.toString(this.plot.getId());
    }

    @Override
    public String getTooltipText() {
        return Long.toString(this.plot.getId()) + " " + this.plot.getName();
    }

    @Override
    public Long getKeyAttributeValue() {
        return this.plot.getId();
    }

    @Override
    public Long getId() {
        return this.plot.getId();
    }

    @Override
    public GridCoverage2D getRaster() {
        return this.raster;
    }

    @Override
    public Plot getObject() {
        return plot;
    }

    public enum KeyAttribute {

        Vi1, Vi2;
    }
}
